import { FormBuilder } from '@angular/forms';
import { _HttpClient } from '@delon/theme';
import { Component, OnInit } from '@angular/core';
import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { RouterModule, Routes } from '@angular/router';
import { SharedModule } from '@shared/shared.module';
import { AccountComponent } from './account/account.component';
import { AccountEditComponent } from './account/account-edit/account-edit.component';
import { OrganizationComponent } from './organization/organization.component';
import { PipeModule } from '@business/pipe/pipe.module';
import { OrganizationEditComponent } from './organization/organization-edit/organization-edit.component';
import { ToolsService } from '@business/services/util/tools.service';
import { OrganizationService } from '@business/services/http/organization.service';
import { AreacodeService } from '@business/services/http/areacode.service';
import { OrganizationConfigComponent } from './organization/organization-config/organization-config.component';
import { OrganizationListComponent } from './organization/organization-list/organization-list.component';
import { RegistrationComponent } from './registration/registration.component';
import { SensorsService } from '@business/services/http/sensors.service';
import { BusinessModule } from '@business/business.module';
import { OrganizationConfigScreenComponent } from './organization/organization-config-screen/organization-config-screen.component';
import { OrganizationConfigUnitComponent } from './organization/organization-config-unit/organization-config-unit.component';

const routes: Routes = [
  {
    path: '',
    children: [
      { path: 'account', component: AccountComponent },
      { path: 'organization', component: OrganizationComponent },
      { path: 'registration', component: RegistrationComponent }
    ]
  }
];

const COMPONENTS_NOROUNT = [ AccountEditComponent, OrganizationEditComponent ];

@NgModule({
  imports: [
    // 管道模块必须当前模块导入
    PipeModule,
    CommonModule,
    SharedModule,
    RouterModule.forChild(routes),
    BusinessModule
  ],
  declarations: [
    ...COMPONENTS_NOROUNT,
    AccountComponent,
    AccountEditComponent,
    OrganizationComponent,
    OrganizationConfigComponent,
    OrganizationListComponent,
    OrganizationConfigScreenComponent,
    OrganizationConfigUnitComponent,
    RegistrationComponent
  ],
  providers: [ToolsService, SensorsService, OrganizationService, _HttpClient, FormBuilder, AreacodeService],
  entryComponents: COMPONENTS_NOROUNT
})
export class SystemsModule { }
